@@ -1,8 +1,6 @@
-/* $Id$ */
-/*
- *      middlelayer.h
+/* File: middlelayer.h
  *
- *      Copyright 2006-2010 Fabian Nowak <timytery@arcor.de>
+ *      Copyright 2006-2017 Fabian Nowak <timytery@arcor.de>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -19,7 +17,6 @@
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-
 #ifndef XFCE4_SENSORS_MIDDLELAYER_H
 #define XFCE4_SENSORS_MIDDLELAYER_H
 
@@ -32,58 +29,55 @@
 
 /**
  * Initialize all sensors detected by iterating and calling init-routines
- * @Param chips: Double-pointer to array of chips
- * @Return Number of initialized features
+ * @param chips: Double-pointer to pointer array of chips
+ * @param suppressmessage [out]: whether to suppress messages when reading the
+ *                               chip
+ * @return Number of initialized features
  */
 int initialize_all (GPtrArray **chips, gboolean *suppressmessage);
 
 
 /**
  * Refresh all features of a chip
- *
- * @Param chip: Pointer to chip
- * @Param data: pointer to t_sensors or NULL;
+ * @param chip: Pointer to chip
+ * @param data: pointer to t_sensors or NULL;
  */
 void refresh_chip (gpointer chip, gpointer data);
 
 
-/**
- * Refresh all features of a chip
- * @Param chips: Pointer to chip pointers
- * @Param sensors: valid pointer to sensors structure or NULL
- */
-/* seems to be pretty unused meanwhile ... */
-/* void refresh_all_chips (GPtrArray *chips, t_sensors *sensors ); */
-
-
 /**
  * Classifies sensor type
- * @Param chipfeature: Pointer to feature
+ * @param chipfeature: Pointer to feature
  */
 void categorize_sensor_type (t_chipfeature *chipfeature);
 
 
 /**
  * Gets value of specified number in chip_name
- * @Param chip_name: takten from libsensors3, it specifies bus and stuff of
+ * @param chip: specifies bus and stuff of
  * the sensors chip feature
- * @Param number: number of chipfeature to look for
- * @Param value: address where double value can be stored
- * @Param suppressmessage: valid pointer to boolean indicating suppression of
+ * @param number: number of chipfeature to look for
+ * @param value: address where double value can be stored
+ * @param suppressmessage: valid pointer to boolean indicating suppression of
  *                         messages, or NULL.
- * @Return 0 on success, >0 else.
+ * @return 0 on success, >0 else.
  */
-int sensor_get_value (t_chip *chip, int number, double *value, gboolean *suppressmessage);
+int sensor_get_value (t_chip *chip, int number, double *value,
+                      gboolean *suppressmessage);
 
 
 /**
  * Free data in chipfeatures
+ * @param chipfeature: pointer to chipfeature to free
+ * @param data: currently unused
  */
 void free_chipfeature (gpointer chipfeature, gpointer data);
 
 
 /**
  * Free remaining structures in chips and associated chipfeatures
+ * @param chip: pointer to chip to free
+ * @param data: currently unused
  */
 void free_chip (gpointer chip, gpointer data);
 
@@ -91,12 +85,14 @@ void free_chip (gpointer chip, gpointer data);
 /**
  * Clean up structures and call library routines for ending "session".
  */
-void sensor_interface_cleanup ();
+void cleanup_interfaces ();
 
 
 /**
  * Refreshes all chips at once.
+ * @param chips: Pointer to pointer array to chips
+ * @param sensors: pointer to sensors structure
  */
-void refresh_all_chips (GPtrArray *chips, t_sensors *sensors );
+void refresh_all_chips (GPtrArray *chips, t_sensors *sensors);
 
 #endif /* XFCE4_SENSORS_MIDDLELAYER_H */
