@@ -1,8 +1,6 @@
-/* $Id$ */
-/*
- *      middlelayer.c
+/* File: middlelayer.c
  *
- *      Copyright 2006-2010 Fabian Nowak <timytery@arcor.de>
+ *      Copyright 2006-2017 Fabian Nowak <timytery@arcor.de>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -56,6 +54,7 @@
 #endif
 
 
+/* -------------------------------------------------------------------------- */
 int
 initialize_all (GPtrArray **chips, gboolean *suppressmessage)
 {
@@ -87,6 +86,7 @@ initialize_all (GPtrArray **chips, gboolean *suppressmessage)
 }
 
 
+/* -------------------------------------------------------------------------- */
 void
 refresh_chip (gpointer chip, gpointer data)
 {
@@ -137,6 +137,7 @@ refresh_chip (gpointer chip, gpointer data)
 }
 
 
+/* -------------------------------------------------------------------------- */
 void
 refresh_all_chips (GPtrArray *chips, t_sensors *sensors )
 {
@@ -148,6 +149,7 @@ refresh_all_chips (GPtrArray *chips, t_sensors *sensors )
 }
 
 
+/* -------------------------------------------------------------------------- */
 void
 categorize_sensor_type (t_chipfeature* chipfeature)
 {
@@ -185,6 +187,7 @@ categorize_sensor_type (t_chipfeature* chipfeature)
 }
 
 
+/* -------------------------------------------------------------------------- */
 int
 sensor_get_value (t_chip *chip, int number, double *value, gboolean *suppressmessage)
 {
@@ -225,9 +228,10 @@ sensor_get_value (t_chip *chip, int number, double *value, gboolean *suppressmes
                 g_assert (number<chip->num_features);
                 feature = (t_chipfeature *) g_ptr_array_index (chip->chip_features, number);
                 g_assert (feature!=NULL);
+                /* TODO: seperate refresh from get operation! */
                 refresh_acpi ((gpointer) feature, NULL);
                 *value = feature->raw_value;
-                return 0; /* HERE    I    AM,    I    WANNA    BE    FIXED    */
+                return 0;
             #else
                 return -1;
             #endif
@@ -238,8 +242,8 @@ sensor_get_value (t_chip *chip, int number, double *value, gboolean *suppressmes
                 g_assert (number<chip->num_features);
                 feature = (t_chipfeature *) g_ptr_array_index (chip->chip_features, number);
                 g_assert (feature!=NULL);
+                /* TODO: seperate refresh from get operation! */
                 refresh_nvidia ((gpointer) feature, NULL);
-                //*value = get_nvidia_value(feature->address);
                 *value = feature->raw_value;
                 return 0;
             #else
@@ -258,6 +262,7 @@ sensor_get_value (t_chip *chip, int number, double *value, gboolean *suppressmes
 }
 
 
+/* -------------------------------------------------------------------------- */
 void
 free_chipfeature (gpointer chipfeature, gpointer data)
 {
@@ -272,21 +277,7 @@ free_chipfeature (gpointer chipfeature, gpointer data)
 }
 
 
-//void
-//free_chipstructure(gpointer data)
-//{
-    //t_chip *ptr_chip_structure = (t_chip*)data;
-    //if (NULL != ptr_chip_structure)
-    //{
-        //g_free(ptr_chip_structure->description);
-        //g_free(ptr_chip_structure->name);
-        //g_free(ptr_chip_structure->sensorId);
-        //// g_free(ptr_chip_structure->chip_name); // is this possible? Does it belong to libsensors3?
-        //g_ptr_array_free(ptr_chip_structure->chip_features, TRUE);
-    //}
-//}
-
-
+/* -------------------------------------------------------------------------- */
 void
 free_chip (gpointer chip, gpointer data)
 {
@@ -313,9 +304,6 @@ free_chip (gpointer chip, gpointer data)
     //}
 //#endif
 
-    // makes program crash
-    //g_free (ptr_chip_structure->chip_name);   /* is a _copied_ structure of libsensors */
-
     g_ptr_array_foreach (ptr_chip_structure->chip_features, free_chipfeature, NULL);
     g_ptr_array_free (ptr_chip_structure->chip_features, TRUE);
     g_free (ptr_chip_structure->chip_name);
@@ -323,8 +311,9 @@ free_chip (gpointer chip, gpointer data)
 }
 
 
+/* -------------------------------------------------------------------------- */
 void
-sensor_interface_cleanup (void)
+cleanup_interfaces (void)
 {
 #ifdef HAVE_LIBSENSORS
     sensors_cleanup();
