@@ -1,5 +1,6 @@
-/* $Id$ */
-/*  Copyright 2008-2010 Fabian Nowak (timystery@arcor.de)
+/* File sensors-interface.c
+ *
+ *   Copyright 2008-2017 Fabian Nowak (timystery@arcor.de)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -53,6 +54,7 @@
 void produce_min_max_values (t_chipfeature *chipfeature, t_tempscale scale, float *minval, float *maxval);
 
 
+/* -------------------------------------------------------------------------- */
 void
 produce_min_max_values (t_chipfeature *chipfeature, t_tempscale scale, float *minval, float *maxval)
 {
@@ -67,6 +69,8 @@ produce_min_max_values (t_chipfeature *chipfeature, t_tempscale scale, float *mi
    }
 }
 
+
+/* -------------------------------------------------------------------------- */
 void
 fill_gtkTreeStore (GtkTreeStore *model, t_chip *chip, t_tempscale scale, t_sensors_dialog *sd)
 {
@@ -157,7 +161,7 @@ fill_gtkTreeStore (GtkTreeStore *model, t_chip *chip, t_tempscale scale, t_senso
 }
 
 
-
+/* -------------------------------------------------------------------------- */
 void
 add_type_box (GtkWidget * vbox, t_sensors_dialog * sd)
 {
@@ -214,7 +218,7 @@ add_type_box (GtkWidget * vbox, t_sensors_dialog * sd)
 }
 
 
-
+/* -------------------------------------------------------------------------- */
 void
 add_update_time_box (GtkWidget * vbox, t_sensors_dialog * sd)
 {
@@ -250,6 +254,7 @@ add_update_time_box (GtkWidget * vbox, t_sensors_dialog * sd)
 }
 
 
+/* -------------------------------------------------------------------------- */
 void
 add_sensor_settings_box ( GtkWidget * vbox, t_sensors_dialog * sd)
 {
@@ -360,6 +365,7 @@ add_sensor_settings_box ( GtkWidget * vbox, t_sensors_dialog * sd)
 }
 
 
+/* -------------------------------------------------------------------------- */
 void
 add_temperature_unit_box (GtkWidget *vbox, t_sensors_dialog *sd)
 {
@@ -398,7 +404,7 @@ add_temperature_unit_box (GtkWidget *vbox, t_sensors_dialog *sd)
 }
 
 
-
+/* -------------------------------------------------------------------------- */
 void
 add_sensors_frame (GtkWidget * notebook, t_sensors_dialog * sd)
 {
@@ -427,6 +433,7 @@ add_sensors_frame (GtkWidget * notebook, t_sensors_dialog * sd)
 }
 
 
+/* -------------------------------------------------------------------------- */
 void
 free_widgets (t_sensors_dialog *ptr_sensors_dialog)
 {
@@ -470,7 +477,7 @@ free_widgets (t_sensors_dialog *ptr_sensors_dialog)
     g_ptr_array_foreach (ptr_sensors_dialog->sensors->chips, free_chip, NULL);
 
     /* stop association to libsensors and others*/
-    sensor_interface_cleanup();
+    cleanup_interfaces();
 
     g_ptr_array_free (ptr_sensors_dialog->sensors->chips, TRUE);
 
@@ -494,6 +501,7 @@ free_widgets (t_sensors_dialog *ptr_sensors_dialog)
 }
 
 
+/* -------------------------------------------------------------------------- */
 void
 init_widgets (t_sensors_dialog *sd)
 {
@@ -506,6 +514,8 @@ init_widgets (t_sensors_dialog *sd)
 
     TRACE ("enters init_widgets");
 
+    g_return_if_fail(sd != NULL);
+
     sensors = sd->sensors;
 
     for (idx_chip=0; idx_chip < sensors->num_sensorchips; idx_chip++) {
@@ -563,7 +573,7 @@ init_widgets (t_sensors_dialog *sd)
 }
 
 
-
+/* -------------------------------------------------------------------------- */
 void
 reload_listbox (t_sensors_dialog *sd)
 {
@@ -574,12 +584,15 @@ reload_listbox (t_sensors_dialog *sd)
 
     TRACE ("enters reload_listbox");
 
+    g_return_if_fail(sd != NULL);
+
     ptr_sensors_structure = sd->sensors;
 
     for (idx_chip=0; idx_chip < ptr_sensors_structure->num_sensorchips; idx_chip++) {
         ptr_chip_structure = (t_chip *) g_ptr_array_index (ptr_sensors_structure->chips, idx_chip);
 
         ptr_tree_store = sd->myListStore[idx_chip];
+        g_assert(ptr_tree_store != NULL);
         gtk_tree_store_clear (ptr_tree_store);
 
         fill_gtkTreeStore (ptr_tree_store, ptr_chip_structure, ptr_sensors_structure->scale, sd);
