@@ -1,6 +1,6 @@
-/* $Id$ */
-
-/*  Copyright 2008-2010 Fabian Nowak (timystery@arcor.de)
+/* File: interface.h
+ *
+ *  Copyright 2008-2017 Fabian Nowak (timystery@arcor.de)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,8 +25,9 @@
 /* Package includes */
 #include <sensors-interface-common.h>
 
+/**
+ * Populate the application's main window
+ * @param sd: pointers to already filled sensors dialog structure
+ * @return newly allocated GtkWidget of main window
+ */
 GtkWidget * create_main_window (t_sensors_dialog *sd);
-
-gboolean draw_callback(GtkWidget    *widget,
-               cairo_t *cr,
-               gpointer      user_data);
